pub struct WatchLockGuard<'a> { /* private fields */ }Expand description
Guard returned by WatchLock::acquire.
Keep this value alive for the duration of the protected read section. The lock is released automatically when the guard is dropped.